Node

Enum Node 

pub enum Node<ID>
where ID: Ord,
{ Id(ID), Subtree(QuorumTree<ID>), }
A child of a QuorumTree.

A node can be either a leaf node ID or a nested quorum tree. Nested trees allow hierarchical quorum rules such as “two data centers, each selected by a local majority”.

Variants



Id(ID)

A leaf node ID.



Subtree(QuorumTree<ID>)

A nested quorum tree.