pub enum Node<ID>where
ID: Ord,{
Id(ID),
Subtree(QuorumTree<ID>),
}Expand description
A child of a QuorumTree.
A node can be either a leaf node ID or a nested quorum tree. Nested trees allow hierarchical quorum rules such as “two data centers, each selected by a local majority”.
Variants