pub trait FindCoherent<ID, Other>{
// Required method
fn find_coherent(&self, other: Other) -> Self;
}Expand description
Finds an intermediate quorum set coherent with both source and target quorum sets.
Required Methods
Sourcefn find_coherent(&self, other: Other) -> Self
fn find_coherent(&self, other: Other) -> Self
Build a quorum set X so that self is coherent with X and X is
coherent with other, i.e., self ~ X ~ other.
Then X is the intermediate quorum set when changing membership from
self to other.
E.g.(cᵢcⱼ is a joint of cᵢ and cⱼ):
c₁.find_coherent(c₁)returnsc₁c₁.find_coherent(c₂)returnsc₁c₂c₁c₂.find_coherent(c₂)returnsc₂c₁c₂.find_coherent(c₁)returnsc₁c₁c2.find_coherent(c₃)returnsc₂c₃
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<NID> FindCoherent<NID, BTreeSet<NID>> for Vec<BTreeSet<NID>>
Builds an intermediate joint quorum set for a target flat config.
impl<NID> FindCoherent<NID, BTreeSet<NID>> for Vec<BTreeSet<NID>>
Builds an intermediate joint quorum set for a target flat config.